==> 1.0.0.tar.gz: lib/flutter_animator.dart <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 Sjoerd van den Berg
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

library flutter_animator;

export 'utils/animator.dart';
export 'utils/perspective.dart';
export 'utils/pair.dart';

export 'widgets/attention_seekers/bounce.dart';
export 'widgets/attention_seekers/flash.dart';
export 'widgets/attention_seekers/head_shake.dart';
export 'widgets/attention_seekers/heart_beat.dart';
export 'widgets/attention_seekers/jello.dart';
export 'widgets/attention_seekers/pulse.dart';
export 'widgets/attention_seekers/rubber_band.dart';
export 'widgets/attention_seekers/shake.dart';
export 'widgets/attention_seekers/swing.dart';
export 'widgets/attention_seekers/tada.dart';
export 'widgets/attention_seekers/wobble.dart';

export 'widgets/bouncing_entrances/bounce_in.dart';
export 'widgets/bouncing_entrances/bounce_in_down.dart';
export 'widgets/bouncing_entrances/bounce_in_left.dart';
export 'widgets/bouncing_entrances/bounce_in_right.dart';
export 'widgets/bouncing_entrances/bounce_in_up.dart';

export 'widgets/bouncing_exits/bounce_out.dart';
export 'widgets/bouncing_exits/bounce_out_down.dart';
export 'widgets/bouncing_exits/bounce_out_left.dart';
export 'widgets/bouncing_exits/bounce_out_right.dart';
export 'widgets/bouncing_exits/bounce_out_up.dart';

export 'widgets/fading_entrances/fade_in.dart';
export 'widgets/fading_entrances/fade_in_down.dart';
export 'widgets/fading_entrances/fade_in_down_big.dart';
export 'widgets/fading_entrances/fade_in_left.dart';
export 'widgets/fading_entrances/fade_in_left_big.dart';
export 'widgets/fading_entrances/fade_in_right.dart';
export 'widgets/fading_entrances/fade_in_right_big.dart';
export 'widgets/fading_entrances/fade_in_up.dart';
export 'widgets/fading_entrances/fade_in_up_big.dart';

export 'widgets/fading_exits/fade_out.dart';
export 'widgets/fading_exits/fade_out_down.dart';
export 'widgets/fading_exits/fade_out_down_big.dart';
export 'widgets/fading_exits/fade_out_left.dart';
export 'widgets/fading_exits/fade_out_left_big.dart';
export 'widgets/fading_exits/fade_out_right.dart';
export 'widgets/fading_exits/fade_out_right_big.dart';
export 'widgets/fading_exits/fade_out_up.dart';
export 'widgets/fading_exits/fade_out_up_big.dart';

export 'widgets/flippers/flip.dart';
export 'widgets/flippers/flip_in_x.dart';
export 'widgets/flippers/flip_in_y.dart';
export 'widgets/flippers/flip_out_x.dart';
export 'widgets/flippers/flip_out_y.dart';

export 'widgets/lightspeed/light_speed_in.dart';
export 'widgets/lightspeed/light_speed_out.dart';

export 'widgets/rotating_entrances/rotate_in.dart';
export 'widgets/rotating_entrances/rotate_in_down_left.dart';
export 'widgets/rotating_entrances/rotate_in_down_right.dart';
export 'widgets/rotating_entrances/rotate_in_up_left.dart';
export 'widgets/rotating_entrances/rotate_in_up_right.dart';

export 'widgets/rotating_exits/rotate_out.dart';
export 'widgets/rotating_exits/rotate_out_down_left.dart';
export 'widgets/rotating_exits/rotate_out_down_right.dart';
export 'widgets/rotating_exits/rotate_out_up_left.dart';
export 'widgets/rotating_exits/rotate_out_up_right.dart';

export 'widgets/sliding_entrances/slide_in_down.dart';
export 'widgets/sliding_entrances/slide_in_left.dart';
export 'widgets/sliding_entrances/slide_in_right.dart';
export 'widgets/sliding_entrances/slide_in_up.dart';

export 'widgets/sliding_exits/slide_out_down.dart';
export 'widgets/sliding_exits/slide_out_left.dart';
export 'widgets/sliding_exits/slide_out_right.dart';
export 'widgets/sliding_exits/slide_out_up.dart';

export 'widgets/specials/hinge.dart';
export 'widgets/specials/jack_in_the_box.dart';
export 'widgets/specials/roll_in.dart';
export 'widgets/specials/roll_out.dart';

export 'widgets/zooming_entrances/zoom_in.dart';
export 'widgets/zooming_entrances/zoom_in_down.dart';
export 'widgets/zooming_entrances/zoom_in_left.dart';
export 'widgets/zooming_entrances/zoom_in_right.dart';
export 'widgets/zooming_entrances/zoom_in_up.dart';

export 'widgets/zooming_exits/zoom_out.dart';
export 'widgets/zooming_exits/zoom_out_down.dart';
export 'widgets/zooming_exits/zoom_out_left.dart';
export 'widgets/zooming_exits/zoom_out_right.dart';
export 'widgets/zooming_exits/zoom_out_up.dart';

==> 1.1.2.tar.gz: lib/flutter_animator.dart <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 Sjoerd van den Berg
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

library flutter_animator;

export 'utils/animator.dart';
export 'utils/perspective.dart';
export 'utils/pair.dart';

export 'widgets/animator_widget.dart';
export 'widgets/attention_seekers/flash.dart';
export 'widgets/attention_seekers/flash.dart';
export 'widgets/attention_seekers/head_shake.dart';
export 'widgets/attention_seekers/heart_beat.dart';
export 'widgets/attention_seekers/jello.dart';
export 'widgets/attention_seekers/pulse.dart';
export 'widgets/attention_seekers/rubber_band.dart';
export 'widgets/attention_seekers/shake.dart';
export 'widgets/attention_seekers/swing.dart';
export 'widgets/attention_seekers/tada.dart';
export 'widgets/attention_seekers/wobble.dart';

export 'widgets/bouncing_entrances/bounce_in.dart';
export 'widgets/bouncing_entrances/bounce_in_down.dart';
export 'widgets/bouncing_entrances/bounce_in_left.dart';
export 'widgets/bouncing_entrances/bounce_in_right.dart';
export 'widgets/bouncing_entrances/bounce_in_up.dart';

export 'widgets/bouncing_exits/bounce_out.dart';
export 'widgets/bouncing_exits/bounce_out_down.dart';
export 'widgets/bouncing_exits/bounce_out_left.dart';
export 'widgets/bouncing_exits/bounce_out_right.dart';
export 'widgets/bouncing_exits/bounce_out_up.dart';

export 'widgets/fading_entrances/fade_in.dart';
export 'widgets/fading_entrances/fade_in_down.dart';
export 'widgets/fading_entrances/fade_in_down_big.dart';
export 'widgets/fading_entrances/fade_in_left.dart';
export 'widgets/fading_entrances/fade_in_left_big.dart';
export 'widgets/fading_entrances/fade_in_right.dart';
export 'widgets/fading_entrances/fade_in_right_big.dart';
export 'widgets/fading_entrances/fade_in_up.dart';
export 'widgets/fading_entrances/fade_in_up_big.dart';

export 'widgets/fading_exits/fade_out.dart';
export 'widgets/fading_exits/fade_out_down.dart';
export 'widgets/fading_exits/fade_out_down_big.dart';
export 'widgets/fading_exits/fade_out_left.dart';
export 'widgets/fading_exits/fade_out_left_big.dart';
export 'widgets/fading_exits/fade_out_right.dart';
export 'widgets/fading_exits/fade_out_right_big.dart';
export 'widgets/fading_exits/fade_out_up.dart';
export 'widgets/fading_exits/fade_out_up_big.dart';

export 'widgets/flippers/flip.dart';
export 'widgets/flippers/flip_in_x.dart';
export 'widgets/flippers/flip_in_y.dart';
export 'widgets/flippers/flip_out_x.dart';
export 'widgets/flippers/flip_out_y.dart';

export 'widgets/lightspeed/light_speed_in.dart';
export 'widgets/lightspeed/light_speed_out.dart';

export 'widgets/rotating_entrances/rotate_in.dart';
export 'widgets/rotating_entrances/rotate_in_down_left.dart';
export 'widgets/rotating_entrances/rotate_in_down_right.dart';
export 'widgets/rotating_entrances/rotate_in_up_left.dart';
export 'widgets/rotating_entrances/rotate_in_up_right.dart';

export 'widgets/rotating_exits/rotate_out.dart';
export 'widgets/rotating_exits/rotate_out_down_left.dart';
export 'widgets/rotating_exits/rotate_out_down_right.dart';
export 'widgets/rotating_exits/rotate_out_up_left.dart';
export 'widgets/rotating_exits/rotate_out_up_right.dart';

export 'widgets/sliding_entrances/slide_in_down.dart';
export 'widgets/sliding_entrances/slide_in_left.dart';
export 'widgets/sliding_entrances/slide_in_right.dart';
export 'widgets/sliding_entrances/slide_in_up.dart';

export 'widgets/sliding_exits/slide_out_down.dart';
export 'widgets/sliding_exits/slide_out_left.dart';
export 'widgets/sliding_exits/slide_out_right.dart';
export 'widgets/sliding_exits/slide_out_up.dart';

export 'widgets/specials/hinge.dart';
export 'widgets/specials/jack_in_the_box.dart';
export 'widgets/specials/roll_in.dart';
export 'widgets/specials/roll_out.dart';

export 'widgets/zooming_entrances/zoom_in.dart';
export 'widgets/zooming_entrances/zoom_in_down.dart';
export 'widgets/zooming_entrances/zoom_in_left.dart';
export 'widgets/zooming_entrances/zoom_in_right.dart';
export 'widgets/zooming_entrances/zoom_in_up.dart';

export 'widgets/zooming_exits/zoom_out.dart';
export 'widgets/zooming_exits/zoom_out_down.dart';
export 'widgets/zooming_exits/zoom_out_left.dart';
export 'widgets/zooming_exits/zoom_out_right.dart';
export 'widgets/zooming_exits/zoom_out_up.dart';
